@@ -383,7 +383,7 @@ on_help_button_clicked (GtkWidget *widget, gpointer user_data)
 	GError *error = NULL;
 
 	gnome_help_display_desktop (NULL, "user-guide",
-				    "wgosnautilus.xml",
+				    "user-guide.xml",
 				    "gosnautilus-469", &error);
 
 	if (error) {
